@@ -89,7 +89,8 @@ class DailyPerformance(object):
         riskfree=0,
         compound=True,
         rolling_sharpe_window=200,
-        trim_outliers=None
+        trim_outliers=None,
+        weights=None,
     ):
 
         self.returns = returns
@@ -122,6 +123,9 @@ class DailyPerformance(object):
         self.riskfree = riskfree
         self.compound = compound
         self.rolling_sharpe_window = rolling_sharpe_window
+        self.weights = weights
+        self.returns_longs = None if self.weights is None else self.returns[self.weights > 0]
+        self.returns_shorts = None if self.weights is None else self.returns[self.weights < 0]
         self._benchmark_prices = benchmark
         self._benchmark_returns = None
         self._benchmark_cum_returns = None
@@ -139,6 +143,10 @@ class DailyPerformance(object):
         self._average_holding_periods_null = None
         self._top_movers = None
         self._bar_size = None
+        self._cagr_shorts = None
+        self._cagr_longs = None
+        self._cum_returns_shorts = None
+        self._cum_returns_longs = None
 
     @classmethod
     def _from_moonshot_or_pnl(cls, results,
@@ -189,6 +197,8 @@ class DailyPerformance(object):
             kwargs["slippages"] = results.loc["Slippage"]
         if "Benchmark" in fields:
             kwargs["benchmark"] = results.loc["Benchmark"]
+        if "Weight" in fields:
+            kwargs["weights"] = results.loc["Weight"]
 
         return cls(**kwargs)
 
@@ -333,12 +343,25 @@ class DailyPerformance(object):
 
     @property
     def cum_returns(self):
-
         if self._cum_returns is None:
             self._cum_returns = get_cum_returns(self.returns, compound=self.compound)
 
         return self._cum_returns
 
+    @property
+    def cum_returns_longs(self):
+        if self._cum_returns_longs is None:
+            self._cum_returns_longs = get_cum_returns(self.returns_longs, compound=self.compound)
+
+        return self._cum_returns_longs
+
+    @property
+    def cum_returns_shorts(self):
+        if self._cum_returns_shorts is None:
+            self._cum_returns_shorts = get_cum_returns(self.returns_shorts, compound=self.compound)
+
+        return self._cum_returns_shorts
+
     @property
     def cum_commissions(self):
 
@@ -370,6 +393,20 @@ class DailyPerformance(object):
 
         return self._cagr
 
+    @property
+    def cagr_longs(self):
+        if self._cagr_longs is None:
+            self._cagr_longs = get_cagr(self.cum_returns_longs, compound=self.compound)
+
+        return self._cagr_longs
+
+    @property
+    def cagr_shorts(self):
+        if self._cagr_shorts is None:
+            self._cagr_shorts = get_cagr(self.cum_returns_shorts, compound=self.compound)
+
+        return self._cagr_shorts
+
     @property
     def sharpe(self):
         if self._sharpe is None:
