@@ -753,6 +753,10 @@ class Tearsheet(BaseTearsheet):
         if show_details:
             self._create_returns_by_year_plots(performance, rows=2, row=2, fig=fig, extra_label="(Details)")
 
+        fig = plt.figure("Returns by Position Type", figsize=(width, height))
+
+        self._create_returns_by_position_type(performance, fig=fig)
+
     def _create_returns_by_year_plots(self, performance, rows, row, fig, extra_label):
 
         color_palette = sns.color_palette()
@@ -792,6 +796,70 @@ class Tearsheet(BaseTearsheet):
 
         fig.tight_layout()
 
+    def _create_returns_by_position_type(self, performance, fig, extra_label=""):
+
+        color_palette = sns.color_palette()
+
+        if isinstance(performance.returns, pd.DataFrame):
+            num_series = len(performance.cum_returns.columns)
+            if num_series > 6:
+                color_palette = sns.color_palette("hls", num_series)
+        else:
+            color_palette = sns.color_palette()[0:1]
+
+        grouped_returns_longs = performance.returns_longs.groupby(performance.returns_longs.index.year)
+        cagrs_by_year_longs = grouped_returns_longs.apply(lambda x: get_cagr(
+            get_cum_returns(x, compound=performance.compound),
+            compound=performance.compound))
+        sharpes_by_year_longs = grouped_returns_longs.apply(get_sharpe, riskfree=performance.riskfree)
+
+        grouped_returns_shorts = performance.returns_shorts.groupby(performance.returns_shorts.index.year)
+        cagrs_by_year_shorts = grouped_returns_shorts.apply(lambda x: get_cagr(
+            get_cum_returns(x, compound=performance.compound),
+            compound=performance.compound))
+        sharpes_by_year_shorts = grouped_returns_shorts.apply(get_sharpe, riskfree=performance.riskfree)
+
+        with sns.color_palette(color_palette):
+            axis = fig.add_subplot(2, 2, 1)
+            axis.set_ylabel("CAGR")
+            self._y_format_as_percentage(axis)
+            plot = cagrs_by_year_longs.plot(ax=axis, kind="bar",
+                                            title="Longs - CAGR by Year {0}".format(extra_label))
+            axis.set_xlabel("")
+            if isinstance(cagrs_by_year_longs, pd.DataFrame):
+                # Remove legend, rely on legend from Sharpe plot
+                plot.legend_.remove()
+
+            axis = fig.add_subplot(2, 2, 2)
+            axis.set_ylabel("Sharpe ratio")
+            self._y_format_at_least_two_decimal_places(axis)
+            plot = sharpes_by_year_longs.plot(ax=axis, kind="bar",
+                                              title="Longs - Sharpe by Year {0}".format(extra_label))
+            axis.set_xlabel("")
+            if isinstance(sharpes_by_year_longs, pd.DataFrame):
+                self._clear_legend(plot)
+
+            axis = fig.add_subplot(2, 2, 3)
+            axis.set_ylabel("CAGR")
+            self._y_format_as_percentage(axis)
+            plot = cagrs_by_year_shorts.plot(ax=axis, kind="bar",
+                                             title="Shorts - CAGR by Year {0}".format(extra_label))
+            axis.set_xlabel("")
+            if isinstance(cagrs_by_year_shorts, pd.DataFrame):
+                # Remove legend, rely on legend from Sharpe plot
+                plot.legend_.remove()
+
+            axis = fig.add_subplot(2, 2, 4)
+            axis.set_ylabel("Sharpe ratio")
+            self._y_format_at_least_two_decimal_places(axis)
+            plot = sharpes_by_year_shorts.plot(ax=axis, kind="bar",
+                                               title="Shorts - Sharpe by Year {0}".format(extra_label))
+            axis.set_xlabel("")
+            if isinstance(sharpes_by_year_shorts, pd.DataFrame):
+                self._clear_legend(plot)
+
+        fig.tight_layout()
+
     def create_montecarlo_tearsheet(self, performance, cycles=5, aggregate_before_shuffle=True):
         """
         Run a Montecarlo simulation by shuffling the DataFrame of returns a specified
